@@ -8,15 +8,28 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2011 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ecLibDb.php 4598 2012-01-17 04:30:08Z fishbone $
+ * @version    SVN: $Id: ecLibDb.php 5385 2012-11-16 01:27:36Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
 
 class ecLibDb extends BaseDb
 {
+	/**
+	 * Eコマース定義値を取得をすべて取得
+	 *
+	 * @param array  $rows			レコード
+	 * @return bool					1行以上取得 = true, 取得なし= false
+	 */
+	function getAllConfig(&$rows)
+	{
+		$queryStr  = 'SELECT * FROM commerce_config ';
+		$queryStr .=   'ORDER BY cg_index';
+		$retValue = $this->selectRecords($queryStr, array(), $rows);
+		return $retValue;
+	}
 	/**
 	 * 通貨情報を取得
 	 *
