@@ -126,9 +126,12 @@ $data_bits[$data_counter]=4;
 
 /*  --- determine encode mode */
 
-if (ereg("[^0-9]",$qrcode_data_string)){
-    if (ereg("[^0-9A-Z \$\*\%\+\-\.\/\:]",$qrcode_data_string)) {
-
+//if (ereg("[^0-9]",$qrcode_data_string)){
+//    if (ereg("[^0-9A-Z \$\*\%\+\-\.\/\:]",$qrcode_data_string)) {
+// PHP 5.3Ή(2010/5/28)
+if (preg_match("/[^0-9]/",$qrcode_data_string)){
+    if (preg_match("/[^0-9A-Z \$\*\%\+\-\.\/\:]/",$qrcode_data_string)) {
+	
      /*  --- 8bit byte mode */
 
         $codeword_num_plus=array(0,0,0,0,0,0,0,0,0,0,
