@@ -10,9 +10,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2011 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: systemManager.php 4241 2011-08-08 05:51:26Z fishbone $
+ * @version    SVN: $Id: systemManager.php 5129 2012-08-22 00:55:21Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');		// Magic3コアクラス
@@ -186,7 +186,7 @@ class SystemManager extends Core
 		// 言語取得
 		$lang = $this->getSystemConfig(self::CF_DEFAULT_LANG);// デフォルト言語
 
-		// サイト定義を読み込む。データが空でもエラーとしない
+		// サイト定義をデフォルト言語で読み込む。データが空でもエラーとしない
 		$ret = $this->db->getAllSiteDefValue($lang, $rows);
 		if ($ret){
 			// 取得データを連想配列にする
@@ -397,24 +397,37 @@ class SystemManager extends Core
 		return $this->adminDefaultTheme;
 	}
 	/**
-	 * デフォルト言語を取得
+	 * デフォルト言語以外のサイト定義を読み込む
 	 *
-	 * @param string	デフォルト言語
+	 * @param string $langId		言語ID
+	 * @return bool					true=成功(指定言語あり)、false=失敗(指定言語なし)
 	 */
-/*	function getDefaultLanguage()
+	function roadSiteDefByLang($langId)
 	{
-		$retValue = '';
-		$queryStr = 'select sc_value from _system_config ';
-		$queryStr .=  'where sc_id = ?';
-		$ret = $this->selectRecord($queryStr, array('default_lang'), $row);
-		if ($ret) $retValue = $row['sc_value'];
-		return $retValue;
-	}*/
+		if ($langId == $this->getSystemConfig(self::CF_DEFAULT_LANG)) return false;
+		
+		// サイト定義を読み込む
+		$ret = $this->db->getAllSiteDefValue($langId, $rows);
+		if ($ret){
+			// 取得データを連想配列にする
+			$defCount = count($rows);
+			for ($i = 0; $i < $defCount; $i++){
+				$key = $rows[$i]['sd_id'];
+				$value = $rows[$i]['sd_value'];
+				
+				// 値が存在した場合のみ上書き
+				if (!empty($value)){
+					$this->_siteDefArray[$key] = $value;
+				}
+			}
+		}
+		return $ret;
+	}
 	/**
 	 * アクセス可能言語を取得
 	 *
 	 * @param bool $reload	再取得するかどうか
-	 * @param array	アクセス可能言語
+	 * @return array	アクセス可能言語
 	 */
 	function getAcceptLanguage($reload = false)
 	{
@@ -431,7 +444,7 @@ class SystemManager extends Core
 	/**
 	 * システムで利用可能な言語を取得
 	 *
-	 * @param array	言語
+	 * @return array	言語
 	 */
 	function getSystemLanguages()
 	{
@@ -444,8 +457,8 @@ class SystemManager extends Core
 	 */
 	public function getMaxFileSizeForUpload()
 	{	
-		$limit = ini_get('upload_max_filesize') > ini_get('post_max_size') ? ini_get('post_max_size') : ini_get('upload_max_filesize');
-		$limit = $limit > ini_get('memory_limit') ? ini_get('memory_limit') : $limit;
+		$limit = convBytes(ini_get('upload_max_filesize')) > convBytes(ini_get('post_max_size')) ? ini_get('post_max_size') : ini_get('upload_max_filesize');
+		$limit = convBytes($limit) > convBytes(ini_get('memory_limit')) ? ini_get('memory_limit') : $limit;
 		return $limit;
 	}
 	/**
