@@ -1,6 +1,6 @@
 <?php
 /**
-* @version		$Id: application.php 4421 2011-11-07 03:07:40Z fishbone $
+* @version		$Id: application.php 4939 2012-06-05 09:45:54Z fishbone $
 * @package		Joomla
 * @copyright	Copyright (C) 2005 - 2008 Open Source Matters. All rights reserved.
 * @license		GNU/GPL, see LICENSE.php
@@ -195,7 +195,7 @@ class JApplication extends JObject
 	 */
 	public function initialise($options = array())
 	{
-		jimport('joomla.plugin.helper');
+/*		jimport('joomla.plugin.helper');
 
 		// Set the language in the class.
 		$config = JFactory::getConfig();
@@ -219,7 +219,7 @@ class JApplication extends JObject
 
 		// Trigger the onAfterInitialise event.
 		JPluginHelper::importPlugin('system');
-		$this->triggerEvent('onAfterInitialise');
+		$this->triggerEvent('onAfterInitialise');*/
 	}
 
 	/**
@@ -236,7 +236,7 @@ class JApplication extends JObject
 	 */
 	public function route()
 	{
-		// Get the full request URI.
+/*		// Get the full request URI.
 		$uri	= clone JURI::getInstance();
 
 		$router = $this->getRouter();
@@ -246,7 +246,7 @@ class JApplication extends JObject
 
 		// Trigger the onAfterRoute event.
 		JPluginHelper::importPlugin('system');
-		$this->triggerEvent('onAfterRoute');
+		$this->triggerEvent('onAfterRoute');*/
 	}
 
 	/**
@@ -264,7 +264,7 @@ class JApplication extends JObject
 	 */
 	public function dispatch($component = null)
 	{
-		$document = JFactory::getDocument();
+/*		$document = JFactory::getDocument();
 
 		$document->setTitle($this->getCfg('sitename'). ' - ' .JText::_('JADMINISTRATION'));
 		$document->setDescription($this->getCfg('MetaDesc'));
@@ -274,7 +274,7 @@ class JApplication extends JObject
 
 		// Trigger the onAfterDispatch event.
 		JPluginHelper::importPlugin('system');
-		$this->triggerEvent('onAfterDispatch');
+		$this->triggerEvent('onAfterDispatch');*/
 	}
 
 	/**
@@ -290,7 +290,7 @@ class JApplication extends JObject
 	 */
 	public function render()
 	{
-		$params = array(
+/*		$params = array(
 			'template'	=> $this->getTemplate(),
 			'file'		=> 'index.php',
 			'directory'	=> JPATH_THEMES,
@@ -310,7 +310,7 @@ class JApplication extends JObject
 		JResponse::setBody($document->render($caching, $params));
 
 		// Trigger the onAfterRender event.
-		$this->triggerEvent('onAfterRender');
+		$this->triggerEvent('onAfterRender');*/
 	}
 
 	/**
@@ -635,95 +635,6 @@ class JApplication extends JObject
 	 */
 	public function login($credentials, $options = array())
 	{
-		// Get the global JAuthentication object.
-		jimport('joomla.user.authentication');
-
-		$authenticate = JAuthentication::getInstance();
-		$response	= $authenticate->authenticate($credentials, $options);
-
-		if ($response->status === JAuthentication::STATUS_SUCCESS) {
-			// validate that the user should be able to login (different to being authenticated)
-			// this permits authentication plugins blocking the user
-			$authorisations = $authenticate->authorise($response, $options);
-			foreach ($authorisations as $authorisation)
-			{
-				$denied_states = Array(JAuthentication::STATUS_EXPIRED, JAuthentication::STATUS_DENIED);
-				if(in_array($authorisation->status, $denied_states))
-				{
-					// Trigger onUserAuthorisationFailure Event.
-					$this->triggerEvent('onUserAuthorisationFailure', array((array)$authorisation));
-
-					// If silent is set, just return false.
-					if (isset($options['silent']) && $options['silent']) {
-						return false;
-					}
-			
-					// Return the error.
-					switch($authorisation->status)
-					{
-						case JAuthentication::STATUS_EXPIRED:
-							return JError::raiseWarning('102002', JText::_('JLIB_LOGIN_EXPIRED'));
-							break;
-						case JAuthentication::STATUS_DENIED:
-							return JError::raiseWarning('102003', JText::_('JLIB_LOGIN_DENIED'));
-							break;
-						default:
-							return JError::raiseWarning('102004', JText::_('JLIB_LOGIN_AUTHORISATION'));
-							break;
-					}
-				}
-			}
-			
-			// Import the user plugin group.
-			JPluginHelper::importPlugin('user');
-
-			// OK, the credentials are authenticated and user is authorised.  Lets fire the onLogin event.
-			$results = $this->triggerEvent('onUserLogin', array((array)$response, $options));
-
-			/*
-			 * If any of the user plugins did not successfully complete the login routine
-			 * then the whole method fails.
-			 *
-			 * Any errors raised should be done in the plugin as this provides the ability
-			 * to provide much more information about why the routine may have failed.
-			 */
-
-			if (!in_array(false, $results, true)) {
-				// Set the remember me cookie if enabled.
-				if (isset($options['remember']) && $options['remember']) {
-					jimport('joomla.utilities.simplecrypt');
-					jimport('joomla.utilities.utility');
-
-					// Create the encryption key, apply extra hardening using the user agent string.
-					$key = JUtility::getHash(@$_SERVER['HTTP_USER_AGENT']);
-
-					$crypt = new JSimpleCrypt($key);
-					$rcookie = $crypt->encrypt(serialize($credentials));
-					$lifetime = time() + 365*24*60*60;
-
-					// Use domain and path set in config for cookie if it exists.
-					$cookie_domain = $this->getCfg('cookie_domain', '');
-					$cookie_path = $this->getCfg('cookie_path', '/');
-					setcookie( JUtility::getHash('JLOGIN_REMEMBER'), $rcookie, $lifetime, $cookie_path, $cookie_domain );
-				}
-
-				return true;
-			}
-		}
-
-		// Trigger onUserLoginFailure Event.
-		$this->triggerEvent('onUserLoginFailure', array((array)$response));
-
-		// If silent is set, just return false.
-		if (isset($options['silent']) && $options['silent']) {
-			return false;
-		}
-
-		// If status is success, any error will have been raised by the user plugin
-		if ($response->status !== JAuthentication::STATUS_SUCCESS) {
-			JError::raiseWarning('102001', JText::_('JLIB_LOGIN_AUTHENTICATE'));
-		}
-
 		return false;
 	}
 
@@ -795,7 +706,10 @@ class JApplication extends JObject
 	 */
 	public function getTemplate($params = false)
 	{
-		return 'system';
+//		return 'system';
+		global $gEnvManager;
+		
+		return $gEnvManager->getCurrentTemplateId();
 	}
 
 	/**
@@ -860,7 +774,7 @@ class JApplication extends JObject
 	 */
 	public function getPathway($name = null, $options = array())
 	{
-		if (!isset($name)) {
+/*		if (!isset($name)) {
 			$name = $this->_name;
 		}
 
@@ -869,7 +783,7 @@ class JApplication extends JObject
 
 		if (JError::isError($pathway)) {
 			return null;
-		}
+		}*/
 
 		return $pathway;
 	}
@@ -884,18 +798,18 @@ class JApplication extends JObject
 	 *
 	 * @since   11.1
 	 */
-	public function getMenu($name = null, $options = array())
+	public static function getMenu($name = null, $options = array())
 	{
 		if (!isset($name)) {
 			$name = $this->_name;
 		}
 
-		jimport('joomla.application.menu');
+//		jimport('joomla.application.menu');
 		$menu = JMenu::getInstance($name, $options);
 
-		if (JError::isError($menu)) {
-			return null;
-		}
+//		if (JError::isError($menu)) {
+//			return null;
+//		}
 
 		return $menu;
 	}
@@ -943,123 +857,6 @@ class JApplication extends JObject
 		return $config;
 	}
 
-	/**
-	 * Create the user session.
-	 *
-	 * Old sessions are flushed based on the configuration value for the cookie
-	 * lifetime. If an existing session, then the last access time is updated.
-	 * If a new session, a session id is generated and a record is created in
-	 * the #__sessions table.
-	 *
-	 * @param   string    $name  The sessions name.
-	 *
-	 * @return  JSession  JSession on success. May call exit() on database error.
-	 *
-	 * @since   11.1
-	 */
-/*	protected function _createSession($name)
-	{
-		$options = array();
-		$options['name'] = $name;
-
-		switch($this->_clientId)
-		{
-			case 0:
-				if ($this->getCfg('force_ssl') == 2) {
-					$options['force_ssl'] = true;
-				}
-				break;
-
-			case 1:
-				if ($this->getCfg('force_ssl') >= 1) {
-					$options['force_ssl'] = true;
-				}
-				break;
-		}
-
-		$session = JFactory::getSession($options);
-
-		//TODO: At some point we need to get away from having session data always in the db.
-
-		$db = JFactory::getDBO();
-
-		// Remove expired sessions from the database.
-		$time = time();
-		if ($time % 2) {
-			// The modulus introduces a little entropy, making the flushing less accurate
-			// but fires the query less than half the time.
-			$query = $db->getQuery(true);
-			$db->setQuery(
-				'DELETE FROM '.$query->qn('#__session') .
-				' WHERE '.$query->qn('time').' < '.(int) ($time - $session->getExpire())
-			);
-			$db->query();
-		}
-
-		// Check to see the the session already exists.
-		if (($this->getCfg('session_handler') != 'database' && ($time % 2 || $session->isNew()))
-			||
-			($this->getCfg('session_handler') == 'database' && $session->isNew())
-		)
-		{
-			$this->checkSession();
-		}
-
-		return $session;
-	}*/
-
-	/**
-	 * Checks the user session.
-	 *
-	 * If the session record doesn't exist, initialise it.
-	 * If session is new, create session variables
-	 *
-	 * @return  void
-	 *
-	 * @since   11.1
-	 */
-/*	public function checkSession()
-	{
-		$db 		= JFactory::getDBO();
-		$session 	= JFactory::getSession();
-		$user		= JFactory::getUser();
-
-		$query = $db->getQuery(true);
-		$db->setQuery(
-			'SELECT '.$query->qn('session_id') .
-			' FROM '.$query->qn('#__session') .
-			' WHERE '.$query->qn('session_id').' = '.$query->q($session->getId()), 0, 1
-		);
-		$exists = $db->loadResult();
-
-		// If the session record doesn't exist initialise it.
-		if (!$exists) {
-			if ($session->isNew()) {
-				$db->setQuery(
-					'INSERT INTO '.$query->qn('#__session').' ('.$query->qn('session_id').', '.$query->qn('client_id').', '.$query->qn('time').')' .
-					' VALUES ('.$query->q($session->getId()).', '.(int) $this->getClientId().', '.(int) time().')'
-				);
-			}
-			else {
-				$db->setQuery(
-					'INSERT INTO `#__session` (`session_id`, `client_id`, `guest`, `time`, `userid`, `username`)' .
-					' VALUES ('.$db->quote($session->getId()).', '.(int) $this->getClientId().', '.(int) $user->get('guest').', '.(int) $session->get('session.timer.start').', '.(int) $user->get('id').', '.$db->quote($user->get('username')).')'
-				);
-			}
-
-			// If the insert failed, exit the application.
-			if (!$db->query()) {
-				jexit($db->getErrorMSG());
-			}
-
-			// Session doesn't exist yet, so create session variables
-			if ($session->isNew()) {
-				$session->set('registry',	new JRegistry('session'));
-				$session->set('user',		new JUser());
-			}
-		}
-	}*/
-
 	/**
 	 * Gets the client id of the current running application.
 	 *
@@ -1152,8 +949,8 @@ class JSite extends JApplication
 	*
 	* @access public
 	*/
-	function initialise( $options = array())
-	{
+//	function initialise( $options = array())
+//	{
 	/*
 		// if a language was specified it has priority
 		// otherwise use user or default language settings
@@ -1180,70 +977,24 @@ class JSite extends JApplication
 
 		parent::initialise($options);
 		*/
-	}
+//	}
 
 	/**
 	* Route the application
 	*
 	* @access public
 	*/
-	function route() {
-		//parent::route();
-	}
-
-	/**
-	* Dispatch the application
-	*
-	* @access public
-	*/
-	function dispatch($component)
-	{
-	/*
-		$document	=& JFactory::getDocument();
-		$user		=& JFactory::getUser();
-		$router     =& $this->getRouter();
-		$params     =& $this->getParams();
-
-		switch($document->getType())
-		{
-			case 'html':
-			{
-				//set metadata
-				$document->setMetaData( 'keywords', $this->getCfg('MetaKeys') );
-
-				if ( $user->get('id') ) {
-					$document->addScript( JURI::root(true).'/includes/js/joomla.javascript.js');
-				}
-
-				if($router->getMode() == JROUTER_MODE_SEF) {
-					$document->setBase(JURI::current());
-				}
-			} break;
-
-			case 'feed':
-			{
-				$document->setBase(JURI::current());
-			} break;
-
-			default: break;
-		}
-
-
-		$document->setTitle( $params->get('page_title') );
-		$document->setDescription( $params->get('page_description') );
-
-		$contents = JComponentHelper::renderComponent($component);
-		$document->setBuffer( $contents, 'component');
-		*/
-	}
+//	function route() {
+//		//parent::route();
+//	}
 
 	/**
 	* Display the application.
 	*
 	* @access public
 	*/
-	function render()
-	{
+//	function render()
+//	{
 	/*
 		$document =& JFactory::getDocument();
 		$user     =& JFactory::getUser();
@@ -1281,7 +1032,7 @@ class JSite extends JApplication
 		$data = $document->render( $this->getCfg('caching'), $params);
 		JResponse::setBody($data);
 		*/
-	}
+//	}
 
    /**
 	* Login authentication function
@@ -1291,8 +1042,8 @@ class JSite extends JApplication
 	* @access public
 	* @see JApplication::login
 	*/
-	function login($credentials, $options = array())
-	{
+//	function login($credentials, $options = array())
+//	{
 	/*
 		 //Set the application login entry point
 		 if(!array_key_exists('entry_url', $options)) {
@@ -1300,8 +1051,8 @@ class JSite extends JApplication
 		 }
 
 		return parent::login($credentials, $options);*/
-		return false;
-	}
+//		return false;
+//	}
 
 	/**
 	* Check if the user can access the application
@@ -1385,75 +1136,10 @@ class JSite extends JApplication
 	 * @return	object	The parameters object
 	 * @since	1.5
 	 */
-	function &getPageParameters( $option = null )
+/*	function &getPageParameters( $option = null )
 	{
 		return $this->getParams( $option );
-	}
-
-	/**
-	 * Get the template
-	 *
-	 * @return string The template name
-	 * @since 1.0
-	 */
-	function getTemplate()
-	{
-		global $gEnvManager;
-		
-		return $gEnvManager->getCurrentTemplateId();
-	/*
-		// Allows for overriding the active template from a component, and caches the result of this function
-		// e.g. $mainframe->setTemplate('solar-flare-ii');
-		if ($template = $this->get('setTemplate')) {
-			return $template;
-		}
-
-		// Get the id of the active menu item
-		$menu =& JSite::getMenu();
-		$item = $menu->getActive();
-
-		$id = 0;
-		if(is_object($item)) { // valid item retrieved
-			$id = $item->id;
-		}
-
-		// Load template entries for the active menuid and the default template
-		$db =& JFactory::getDBO();
-		$query = 'SELECT template'
-			. ' FROM #__templates_menu'
-			. ' WHERE client_id = 0 AND (menuid = 0 OR menuid = '.(int) $id.')'
-			. ' ORDER BY menuid DESC'
-			;
-		$db->setQuery($query, 0, 1);
-		$template = $db->loadResult();
-
-		// Allows for overriding the active template from the request
-		$template = JRequest::getCmd('template', $template);
-		$template = JFilterInput::clean($template, 'cmd'); // need to filter the default value as well
-
-		// Fallback template
-		if (!file_exists(JPATH_THEMES.DS.$template.DS.'index.php')) {
-			$template = 'rhuk_milkyway';
-		}
-
-		// Cache the result
-		$this->set('setTemplate', $template);
-		return $template;
-		*/
-	}
-
-	/**
-	 * Overrides the default template that would be used
-	 *
-	 * @param string The template name
-	 */
-	function setTemplate( $template )
-	{
-		/*if (is_dir(JPATH_THEMES.DS.$template)) {
-			$this->set('setTemplate', $template);
-		}*/
-	}
-
+	}*/
 	/**
 	 * Return a reference to the JPathway object.
 	 *
@@ -1461,45 +1147,17 @@ class JSite extends JApplication
 	 * @return object JPathway.
 	 * @since 1.5
 	 */
-	function &getMenu()
+	//function &getMenu()
+	static function &getMenu($name = null, $options = array())
 	{
 //		$options = array();
-//		$menu =& parent::getMenu('site', $options);
+//		$menu = parent::getMenu('site', $options);
 
-		$menu =& JMenu::getInstance('site', $options);
+		$menu = JMenu::getInstance('site', $options);
 /*		if (JError::isError($menu)) {
 			$null = null;
 			return $null;
 		}*/
 		return $menu;
 	}
-
-	/**
-	 * Return a reference to the JPathway object.
-	 *
-	 * @access public
-	 * @return object JPathway.
-	 * @since 1.5
-	 */
-	function &getPathWay()
-	{
-		$options = array();
-//		$pathway =& parent::getPathway('site', $options);
-		return $pathway;
-	}
-
-	/**
-	 * Return a reference to the JRouter object.
-	 *
-	 * @access	public
-	 * @return	JRouter.
-	 * @since	1.5
-	 */
-/*	function &getRouter()
-	{
-		$config =& JFactory::getConfig();
-		$options['mode'] = $config->getValue('config.sef');
-//		$router =& parent::getRouter('site', $options);
-		return $router;
-	}*/
 }
