@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2012 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: _develop.sql 5365 2012-11-07 14:40:33Z fishbone $
+-- * @version    SVN: $Id: _develop.sql 5409 2012-11-24 10:10:14Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- [開発ウィジェット登録]   *****仕様変更あり注意*****
@@ -22,20 +22,20 @@
 -- ウィジェット情報
 DELETE FROM _widgets WHERE wd_id = 'photo_cart';
 INSERT INTO _widgets 
-(wd_id,        wd_name,                     wd_version, wd_author,      wd_copyright, wd_license,                wd_license_type, wd_official_level, wd_description, wd_has_admin, wd_initialized, wd_launch_index, wd_cache_type, wd_view_control_type, wd_install_dt, wd_create_dt) VALUES
-('photo_cart', 'フォトギャラリー - カート', '1.1.0',    'Naoki Hirata', 'Magic3.org', 'Magic3 Commerce License', 1,               10,                'フォトギャラリーのカート内の商品を表示するオプションウィジェット。',   true,    true,           100, 0, 0, now(),      now());
+(wd_id,        wd_name,                     wd_version, wd_author,      wd_copyright, wd_license,                wd_license_type, wd_official_level, wd_description, wd_has_admin, wd_initialized, wd_launch_index, wd_cache_type, wd_view_control_type, wd_release_dt, wd_install_dt, wd_create_dt) VALUES
+('photo_cart', 'フォトギャラリー - カート', '1.1.0',    'Naoki Hirata', 'Magic3.org', 'Magic3 Commerce License', 1,               10,                'フォトギャラリーのカート内の商品を表示するオプションウィジェット。',   true,    true,           100, 0, 0, '2012-11-24',now(),      now());
 DELETE FROM _widgets WHERE wd_id = 'photo_shop';
 INSERT INTO _widgets
-(wd_id,     wd_name,              wd_type, wd_edit_content, wd_version, wd_author,      wd_copyright, wd_license, wd_license_type, wd_official_level, wd_description,                                                        wd_has_admin, wd_initialized, wd_cache_type, wd_view_control_type, wd_install_dt, wd_create_dt) VALUES
-('photo_shop', 'フォトギャラリー - ショップ', 'product', true, '1.0.0',    'Naoki Hirata', 'Magic3.org', 'Magic3 Commerce License',   1,   10,                'フォトギャラリーの商品購入オプションウィジェット。', true,         true,   0, 2, now(), now());
+(wd_id,     wd_name,              wd_type, wd_edit_content, wd_version, wd_author,      wd_copyright, wd_license, wd_license_type, wd_official_level, wd_description,                                                        wd_has_admin, wd_initialized, wd_cache_type, wd_view_control_type, wd_release_dt, wd_install_dt, wd_create_dt) VALUES
+('photo_shop', 'フォトギャラリー - ショップ', 'product', true, '1.0.0',    'Naoki Hirata', 'Magic3.org', 'Magic3 Commerce License',   1,   10,                'フォトギャラリーの商品購入オプションウィジェット。', true,         true,   0, 2, '2012-11-24',now(), now());
 DELETE FROM _widgets WHERE wd_id = 'photo_login';
 INSERT INTO _widgets
-(wd_id,         wd_name,                       wd_version, wd_author,      wd_copyright, wd_license,                wd_license_type, wd_official_level, wd_description, wd_add_script_lib, wd_has_admin, wd_initialized, wd_cache_type, wd_view_control_type, wd_install_dt, wd_create_dt) VALUES
-('photo_login', 'フォトギャラリー - ログイン', '1.0.0',    'Naoki Hirata', 'Magic3.org', 'Magic3 Commerce License', 1,               10, 'フォトギャラリーの会員ログイン用ボックス。', 'md5',     false,     true,           2, -1, now(), now());
+(wd_id,         wd_name,                       wd_version, wd_author,      wd_copyright, wd_license,                wd_license_type, wd_official_level, wd_description, wd_add_script_lib, wd_has_admin, wd_initialized, wd_cache_type, wd_view_control_type, wd_release_dt, wd_install_dt, wd_create_dt) VALUES
+('photo_login', 'フォトギャラリー - ログイン', '1.0.0',    'Naoki Hirata', 'Magic3.org', 'Magic3 Commerce License', 1,               10, 'フォトギャラリーの会員ログイン用ボックス。', 'md5',     false,     true,           2, -1, '2012-11-24',now(), now());
 DELETE FROM _widgets WHERE wd_id = 'ec_product_carousel';
 INSERT INTO _widgets
-(wd_id,         wd_name,               wd_version, wd_author,      wd_copyright, wd_license, wd_official_level, wd_description, wd_add_script_lib, wd_add_script_lib_a,   wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_initialized, wd_cache_type, wd_view_control_type, wd_release_dt, wd_install_dt, wd_create_dt) VALUES
-('ec_product_carousel', 'Eコマース - 商品カルーセル表示', '1.0.0',    'Naoki Hirata', 'Magic3.org', 'GPL',      10, '商品画像をランダムでカルーセル表示する。', 'jquery.cloudcarousel,jquery.mousewheel', '',   true,        false,               false,true,           0, 0, '2012-11-01', now(), now());
+(wd_id,         wd_name,               wd_version, wd_author,      wd_copyright, wd_license, wd_official_level, wd_description, wd_add_script_lib, wd_add_script_lib_a,   wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_initialized, wd_cache_type, wd_view_control_type, wd_release_dt, wd_release_dt, wd_install_dt, wd_create_dt) VALUES
+('ec_product_carousel', 'Eコマース - 商品カルーセル表示', '1.0.0',    'Naoki Hirata', 'Magic3.org', 'GPL',      10, '商品画像をランダムでカルーセル表示する。', 'jquery.cloudcarousel,jquery.mousewheel', '',   true,        false,               false,true,           0, 0, '2012-11-01', '2012-11-24',now(), now());
 
 -- インナーウィジェット(配送方法)
 DELETE FROM _iwidgets WHERE iw_widget_id = 'photo_shop' AND iw_id = 'flatrate';
@@ -67,6 +67,11 @@ DELETE FROM _iwidgets WHERE iw_widget_id = 'photo_shop' AND iw_id = 'epsilon';
 INSERT INTO _iwidgets
 (iw_widget_id, iw_id,     iw_name,          iw_type,    iw_author,      iw_copyright, iw_license,               iw_license_type, iw_official_level, iw_online, iw_install_dt, iw_create_dt) VALUES
 ('photo_shop', 'epsilon', 'イプシロン決済', 'PAYMENT', 'Naoki Hirata', 'Magic3.org', 'Magic3 Commerce License', 1,               10,                true,      now(),         now());
+DELETE FROM _iwidgets WHERE iw_widget_id = 'photo_shop' AND iw_id = 'exchange_classrate';
+INSERT INTO _iwidgets
+(iw_widget_id, iw_id,     iw_name,          iw_type,    iw_author,      iw_copyright, iw_license,               iw_license_type, iw_official_level, iw_online, iw_install_dt, iw_create_dt) VALUES
+('photo_shop', 'exchange_classrate', '代金引換(購入額基準)', 'PAYMENT', 'Naoki Hirata', 'Magic3.org', 'Magic3 Commerce License', 1,               10,                false,      now(),         now());
+
 -- インナーウィジェット(注文計算)
 DELETE FROM _iwidgets WHERE iw_widget_id = 'photo_shop' AND iw_id = 'lotbuying';
 INSERT INTO _iwidgets
@@ -98,7 +103,7 @@ INSERT INTO photo_config
 ('shop_email',        '',                 'ショップ宛てメールアドレス',             17),
 ('auto_email_sender', '',                 '自動送信メール送信元アドレス',           18),
 ('use_member_address', '1',               '会員登録の住所使用',                     19),
-('auto_regist_member', '0',               '自動会員登録',                           20),
+('auto_regist_member', '1',               '自動会員登録',                           20),
 ('sell_product_photo', '1',               'フォト商品販売',                         21),
 ('sell_product_download', '1',            'ダウンロード商品販売',                   22),
 ('member_notice', '',                     '会員向けお知らせ',                       23),
@@ -168,13 +173,3 @@ INSERT INTO _nav_item
 (503,   500,          2,        'admin_menu', 'configwidget_photo_shop',       '',             0,               'task=member',   '会員管理', '会員管理', '会員情報を管理します。', true),
 (600,   0,            4,        'admin_menu', '_content',                      '',          0,               '',       'コンテンツ管理', 'コンテンツ管理', '各種コンテンツを管理します。', true),
 (601,   600,          0,        'admin_menu', 'configwidget_banner3',        '',          0,               '',       'バナー', 'バナー', 'バナーを管理します。(バナーメインウィジェット)', true);
-
-
--- ブログエントリー(記事)マスター
-ALTER TABLE blog_entry ADD be_create_thumb            BOOLEAN        DEFAULT true                  NOT NULL;      -- サムネール作成するかどうか
-
--- 汎用コンテンツマスター
-ALTER TABLE content ADD cn_create_thumb            BOOLEAN        DEFAULT true                  NOT NULL;      -- サムネール作成するかどうか
-
--- ログインユーザマスター
-ALTER TABLE _login_user ADD lu_user_pwd            BOOLEAN        DEFAULT false                  NOT NULL;      -- ユーザが設定したパスワードかどうか
