@@ -7,9 +7,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2011 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m3admin_widget1.5.1.js 4437 2011-11-09 03:20:08Z fishbone $
+ * @version    SVN: $Id: m3admin_widget1.4.0.js 3310 2010-06-29 09:49:32Z fishbone $
  * @link       http://www.magic3.org
  */
 (function($){
@@ -126,9 +126,6 @@
 	var setupSortable = function(){
 		var els = M3_POSITIONS;
 		var $els = $(els.toString());
-		var urlParams = m3_getUrlParam(document.URL);
-		var page = urlParams['_page'];
-		var sub = urlParams['_sub'];
 		
 		// チェックボックス追加
 		$('dt.m3_widget_with_check_box', $els).append('<span class="options"><a class="m3_widget_close">close</a></span>');
@@ -141,7 +138,7 @@
 			cursor: 'move',
 			cursorAt: { top: 0, left: 0 },
 			opacity: 0.5,
-			helper: 'clone',
+			//helper: 'clone',
 			appendTo: 'body',
 			//placeholder: 'clone',
 			//placeholder: 'placeholder',
@@ -176,7 +173,7 @@
 				},
 				'm3_wadjust': function(t){
 					var attrs = m3_splitAttr($('#' + t.id).attr('m3'));
-					m3ShowAdjustWindow(attrs['configid'], attrs['serial'], page, sub);
+					m3ShowAdjustWindow(attrs['configid'], attrs['serial']);
 				},
 				'm3_wshared': function(t){
 					m3TaskWidget('toggle', $('#' + t.id));
@@ -210,9 +207,9 @@
 	};
 	var changeSortable = function(e, ui){
 		if(ui.sender){
-			var w = ui.item.width();
+			var w = ui.element.width();
 			ui.placeholder.width(w);
-			ui.helper.css("width", w);
+			ui.helper.css("width",ui.element.children().width());
 		}
 	};
 	
@@ -220,7 +217,7 @@
 		var obj = $('#' + ui.item[0].id);
 		var recvPosObj = obj.parents('.m3_widgetpos_box');	// 移動先ポジション
 		var pos = '';
-		if (recvPosObj.attr('id') == $(this).attr('id')){
+		if (recvPosObj.attr('id') == ui.element[0].id){
 			if (ui.sender){
 				var senderObj = $('#' + ui.sender[0].id);
 				var attrs = m3_splitAttr(senderObj.attr('m3'));
@@ -232,9 +229,11 @@
 	
 	var dragChange = function(e, ui){
 		if(ui.sender){
-			/*var w = ui.item.width();
+				
+			/*var w = ui.element.width();
 			ui.placeholder.width(w);
-			ui.helper.css("width",ui.item.children().width());*/
+			ui.helper.css("width",ui.element.children().width());*/
+			
 		}
 		$('dl.m3_widget_sortable').css("margin-top", '100px');
 	};
@@ -352,7 +351,7 @@
 	};
 	$(document).ready(function(){
 		//var widgetWindow = '<div id="m3_widget_window" style="position:absolute;width:250;top:0;left:0;">';
-		var widgetWindow = '<div id="m3_widget_window" style="position:absolute;width:250;top:105px;left:0;">';
+		var widgetWindow = '<div id="m3_widget_window" style="position:absolute;width:250;top:50px;left:0;">';
 		widgetWindow += '<table border="1px" width="250" bgcolor="#424242" cellspacing="0">';
 		widgetWindow += '<tr>';
 		widgetWindow += '<td width="100%">';
