@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainMenudefWidgetContainer.php 4979 2012-06-19 05:53:00Z fishbone $
+ * @version    SVN: $Id: admin_mainMenudefWidgetContainer.php 5324 2012-10-26 05:22:45Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -19,7 +19,7 @@ require_once($gEnvManager->getCurrentWidgetDbPath() . '/admin_mainDb.php');
 class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
-	private $serialNo;		// 選択中の項目のシリアル番号
+	private $serialNo;		// 選択中の項目のシリアル番号(メニュー項目IDを使用)
 	private $serialArray = array();			// 表示中のシリアル番号
 	private $currentPageSubId;	// 現在のページサブID
 	private $contentId;			// 現在のコンテンツID
