@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainUserlistWidgetContainer.php 4993 2012-06-26 12:14:34Z fishbone $
+ * @version    SVN: $Id: admin_mainUserlistWidgetContainer.php 5260 2012-10-01 00:30:26Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_mainUserBaseWidgetContainer.php');
@@ -290,7 +290,8 @@ class admin_mainUserlistWidgetContainer extends admin_mainUserBaseWidgetContaine
 		if ($act == 'update'){		// 行更新のとき
 			// 入力チェック
 			$this->checkInput($name, $this->_('Name'));		// 名前
-			$this->checkInput($account, $this->_('Login Account'));	// アカウント
+			//$this->checkInput($account, $this->_('Login Account'));	// アカウント
+			$this->checkLoginAccount($account, $this->_('Login Account'), true);// アカウント
 			$this->checkMailAddress($email, $this->_('Email'), true);		// Eメール
 		
 			// 期間範囲のチェック
@@ -351,7 +352,8 @@ class admin_mainUserlistWidgetContainer extends admin_mainUserBaseWidgetContaine
 		} else if ($act == 'add'){		// 新規追加のとき
 			// 入力チェック
 			$this->checkInput($name, $this->_('Name'));		// 名前
-			$this->checkInput($account, $this->_('Login Account'));	// アカウント
+			//$this->checkInput($account, $this->_('Login Account'));	// アカウント
+			$this->checkLoginAccount($account, $this->_('Login Account'), true);// アカウント
 			$this->checkMailAddress($email, $this->_('Email'), true);		// Eメール
 			if ($this->userType == '') $this->setUserErrorMsg($this->_('User type not selected.'));		// ユーザ種別が選択されていません
 			
