@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_menu3WidgetContainer.php 5063 2012-07-24 07:44:35Z fishbone $
+ * @version    SVN: $Id: admin_menu3WidgetContainer.php 5112 2012-08-16 00:54:13Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -215,7 +215,7 @@ class admin_menu3WidgetContainer extends BaseAdminWidgetContainer
 			
 			// サイト表示
 			$siteName = $this->gEnv->getSiteName();
-			if (empty($siteName)) $siteName = $this->_('Untitled Site');
+//			if (empty($siteName)) $siteName = $this->_('Untitled Site');
 			$siteName = makeTruncStr($siteName, self::MAX_SITENAME_LENGTH);
 			$siteUrl = $this->gEnv->getRootUrl();
 			$this->tmpl->addVar("menu", "site_name", $siteName);
