@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_default_contentContentWidgetContainer.php 5143 2012-08-27 13:39:55Z fishbone $
+ * @version    SVN: $Id: admin_default_contentContentWidgetContainer.php 5220 2012-09-18 12:15:45Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getWidgetContainerPath('default_content') . '/admin_default_contentBaseWidgetContainer.php');
@@ -627,7 +627,7 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 			} else {
 				$destStr = $this->gInstance->getAjaxManager()->createJsonString($resultObj);
 			}
-			$destStr = htmlspecialchars($destStr, ENT_NOQUOTES);
+			//$destStr = htmlspecialchars($destStr, ENT_NOQUOTES);// 「&」が「&amp;」に変換されるので使用しない
 			//header('Content-type: application/json; charset=utf-8');
 			header('Content-Type: text/html; charset=UTF-8');		// JSONタイプを指定するとIE8で動作しないのでHTMLタイプを指定
 			echo $destStr;
