@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_dispProductWidgetContainer.php 5370 2012-11-10 12:58:17Z fishbone $
+ * @version    SVN: $Id: ec_dispProductWidgetContainer.php 5398 2012-11-22 02:29:37Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -20,6 +20,7 @@ require_once($gEnvManager->getCommonPath() . '/valueCheck.php');
 class ec_dispProductWidgetContainer extends BaseWidgetContainer
 {
 	private $db;			// DB接続オブジェクト
+	private $langId;		// 現在の言語ID
 	private $viewStyle;		// 表示スタイル
 	private $categoryId;		// カテゴリーID
 	private $productId;			// 製品ID
@@ -51,6 +52,9 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 	const DEFAULT_STOCK_VIEW_FORMAT = '0:なし;3:残り僅か($1);:あり($1)';
 	const DEFAULT_PRODUCT_IMAGE_TYPE = 'c.jpg';			// 商品画像ファイルのタイプ
 	const PRODUCT_IMAGE_DIR = '/widgets/product/image/';				// 商品画像格納ディレクトリ
+	const MAX_CATEGORY_LEVEL = 5;			// カテゴリー階層最大数
+	// Eコマース設定DB値
+	const CF_E_HIERARCHICAL_CATEGORY	= 'hierarchical_category';	// 階層化商品カテゴリー
 	
 	/**
 	 * コンストラクタ
@@ -106,7 +110,7 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 		// 現在日時を取得
 		$this->currentDay = date("Y/m/d");		// 日
 		$this->currentHour = (int)date("H");		// 時間
-		$langId	= $this->gEnv->getCurrentLanguage();		// 表示言語を取得
+		$this->langId	= $this->gEnv->getCurrentLanguage();		// 表示言語を取得
 		$this->currentPageUrl = $this->gEnv->createCurrentPageUrl();// 現在のページURL
 		
 		// 保存値取得
@@ -152,9 +156,18 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 		}
 				
 		// パラメータを取得
+		// カテゴリーを取得
 		$this->categoryId = $request->trimValueOf('category');	// カテゴリーID
 		$categoryArray = explode(',', $this->categoryId);
-		if (!ValueCheck::isNumeric($categoryArray)) $this->categoryId = '';		// すべて数値であるかチェック
+		if (!ValueCheck::isNumeric($categoryArray)){
+			$this->categoryId = '';		// すべて数値であるかチェック
+			$categoryArray = array();
+		}
+		if (!empty($categoryArray) && $this->ecObj->getConfig(self::CF_E_HIERARCHICAL_CATEGORY)){			// サブカテゴリーを取得する場合
+			$categoryArray = array_unique($this->getSubCategory($categoryArray));
+			$this->categoryId = implode(',', $categoryArray);
+		}
+		
 		$pageNo = $request->trimValueOf(M3_REQUEST_PARAM_PAGE_NO);				// ページ番号
 		if (empty($pageNo)) $pageNo = 1;
 		$quantity = $request->trimValueOf('item_quantity');		// 数量
@@ -185,7 +198,7 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 				$cartSerial = 0;		// カートシリアル番号
 				$cartItemSerial = 0;	// カート商品シリアル番号
 				$userId = $this->gEnv->getCurrentUserId();
-				$ret = $this->ecObj->db->getCartHead($cartId, $langId, $row);
+				$ret = $this->ecObj->db->getCartHead($cartId, $this->langId, $row);
 				if ($ret){
 					$cartSerial = $row['sh_serial'];
 					if ($userId == 0) $userId = $row['sh_id'];
@@ -193,7 +206,7 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 				
 				// 商品情報を取得
 				$isValidItem = true;		// 現在のカートのデータが有効かどうか
-				$ret = $this->db->getProductByProductId($this->productId, $langId, $row, $row2, $row3, $row4, $row5);
+				$ret = $this->db->getProductByProductId($this->productId, $this->langId, $row, $row2, $row3, $row4, $row5);
 				if ($ret){
 					// 価格を取得
 					$priceArray = $this->getPrice($row2, self::STANDARD_PRICE);
@@ -202,8 +215,8 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 					$taxType = $row['pt_tax_type_id'];					// 税種別			
 
 					// 価格作成
-					$this->ecObj->setCurrencyType($currency, $langId);		// 通貨設定
-					$this->ecObj->setTaxType($taxType, $langId);		// 税種別設定
+					$this->ecObj->setCurrencyType($currency, $this->langId);		// 通貨設定
+					$this->ecObj->setTaxType($taxType, $this->langId);		// 税種別設定
 					$totalPrice = $this->ecObj->getPriceWithTax($price, $dispPrice);	// 税込み価格取得
 				} else {		// 商品情報が取得できないときは、カートの商品をキャンセル
 					$isValidItem = false;
@@ -229,7 +242,7 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 				// カート商品情報を更新
 				if ($isValidItem){
 					// カートに商品を追加
-					$ret = $this->ecObj->db->addCartItem($cartSerial, $cartItemSerial, $cartId, self::PRODUCT_CLASS_DEFAULT, $this->productId, self::PRODUCT_TYPE_DEFAULT, $langId, 
+					$ret = $this->ecObj->db->addCartItem($cartSerial, $cartItemSerial, $cartId, self::PRODUCT_CLASS_DEFAULT, $this->productId, self::PRODUCT_TYPE_DEFAULT, $this->langId, 
 														$currency, $totalPrice, $quantity);
 				} else {
 					// カート商品の無効化
@@ -262,8 +275,8 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 					$this->gInstance->getAnalyzeManager()->logSearchWord($this->gEnv->getCurrentWidgetId(), $parsedKeywords[$i]);
 				}
 				
-				//$totalCount = $this->db->getProductCountByKeyword($keyword, $langId, 1);
-				$totalCount = $this->db->getProductCountByKeyword($parsedKeywords, $langId, 1);
+				//$totalCount = $this->db->getProductCountByKeyword($keyword, $this->langId, 1);
+				$totalCount = $this->db->getProductCountByKeyword($parsedKeywords, $this->langId, 1);
 				$pageCount = (int)(($totalCount -1) / $productCount) + 1;		// 総ページ数
 				
 				// 表示するページ番号の修正
@@ -271,8 +284,8 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 				if ($pageNo > $pageCount) $pageNo = $pageCount;
 				
 				// 商品リストを表示
-				//$this->db->getProductByKeyword($keyword, $langId, $productCount, ($pageNo -1) * $productCount, array($this, 'productListLoop'));
-				$this->db->getProductByKeyword($parsedKeywords, $langId, $productCount, ($pageNo -1) * $productCount, array($this, 'productListLoop'));
+				//$this->db->getProductByKeyword($keyword, $this->langId, $productCount, ($pageNo -1) * $productCount, array($this, 'productListLoop'));
+				$this->db->getProductByKeyword($parsedKeywords, $this->langId, $productCount, ($pageNo -1) * $productCount, array($this, 'productListLoop'));
 
 				// ページング用リンク作成
 				$pageLink = '';
@@ -302,13 +315,10 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 					$this->tmpl->addVar("no_item_message", "detail", 'キーワード=' . $keyword . '&nbsp;&nbsp;' . $totalCount . '件');// 詳細
 				}
 			} else {
-				// サブカテゴリーリストを取得
-				//if (!empty($this->categoryId)) $this->db->getCategoryList($this->categoryId, $langId, array($this, 'categoryListLoop'));
-	
 				// 指定カテゴリーの商品を取得
 				if (!empty($this->categoryId)){
 					// 総数を取得
-					$totalCount = $this->db->getProductCountByCategoryId($this->categoryId, $langId);
+					$totalCount = $this->db->getProductCountByCategoryId($this->categoryId, $this->langId);
 					$pageCount = (int)(($totalCount -1) / $productCount) + 1;		// 総ページ数
 			
 					// 表示するページ番号の修正
@@ -316,13 +326,15 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 					if ($pageNo > $pageCount) $pageNo = $pageCount;
 
 					// 商品リストを表示
-					$this->db->getProductByCategoryId($this->categoryId, $langId, $productCount, ($pageNo -1) * $productCount, array($this, 'productListLoop'));
+					$this->db->getProductByCategoryId($this->categoryId, $this->langId, $productCount, ($pageNo -1) * $productCount, array($this, 'productListLoop'));
 
 					// ページング用リンク作成
+					// カテゴリーはアクセス時のパラメータを使用
+					$categoryId = $request->trimValueOf('category');	// カテゴリーID
 					$pageLink = '';
 					if ($pageCount > 1){	// ページが2ページ以上のときリンクを作成
 						for ($i = 1; $i <= $pageCount; $i++){
-							$linkUrl = $this->currentPageUrl . '&category=' . $this->categoryId . '&page=' . $i;
+							$linkUrl = $this->currentPageUrl . '&category=' . $categoryId . '&page=' . $i;
 							if ($i == $pageNo){
 								$link = '&nbsp;' . $i;
 							} else {
@@ -352,7 +364,7 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 			// 表示モードは画像大
 			$this->viewStyle = self::VIEW_STYLE_LARGE;
 			
-			$ret = $this->db->getProductByProductId($this->productId, $langId, $row, $row2, $row3, $row4, $row5);
+			$ret = $this->db->getProductByProductId($this->productId, $this->langId, $row, $row2, $row3, $row4, $row5);
 			if ($ret){
 				// 取得値を設定
 				//$this->serialNo = $row['pt_serial'];		// シリアル番号
@@ -362,7 +374,7 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 				$unitTypeId = $row['pt_unit_type_id'];	// 単位
 				// 単位情報を取得
 				$unitType = '';
-				if ($this->db->getUnitTypeRecord($unitTypeId, $langId, $unitRow)){
+				if ($this->db->getUnitTypeRecord($unitTypeId, $this->langId, $unitRow)){
 					$unitType = $unitRow['ut_symbol'];
 				}
 				$unitQuantity = $row['pt_unit_quantity'];		// 数量
@@ -379,7 +391,9 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 				$currency = $priceArray['pp_currency_id'];	// 通貨
 				$taxType = $row['pt_tax_type_id'];					// 税種別
 				$lang = $row['pt_language_id'];					// 言語				
-
+				$prePrice = $this->convertToDispString($priceArray['cu_symbol']);
+				$postPrice = $this->convertToDispString($priceArray['cu_post_symbol']);
+			
 				// 表示額作成
 				$this->ecObj->setCurrencyType($currency, $lang);		// 通貨設定
 				$this->ecObj->setTaxType($taxType, $lang);		// 税種別設定
@@ -447,7 +461,7 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 				
 				//$this->tmpl->addVar("_widget", "url", $url);				// 詳細情報URL
 				//$this->tmpl->addVar("_widget", "admin_note", $adminNote);			// 管理者用備考
-				$this->tmpl->addVar("_widget", "disp_total_price", $dispPrice);		// 税込み価格
+				$this->tmpl->addVar("_widget", "disp_total_price", $prePrice . $dispPrice . $postPrice);		// 税込み価格
 //				$this->tmpl->addVar("_widget", "image_m", $destImg_m);		// 画像
 				$this->tmpl->addVar("_widget", "image_l", $destImg_l);		// 画像
 				$this->tmpl->addVar("_widget", "productid_key", M3_REQUEST_PARAM_PRODUCT_ID);		// 商品IDキー
@@ -489,33 +503,6 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 			}
 		}
 	}
-	/**
-	 * 取得したデータをテンプレートに設定する
-	 *
-	 * @param int $index			行番号(0～)
-	 * @param array $fetchedRow		フェッチ取得した行
-	 * @param object $param			未使用
-	 * @return bool					true=処理続行の場合、false=処理終了の場合
-	 */
-	function categoryListLoop($index, $fetchedRow, $param)
-	{
-		// リンクを作成
-		$name = $this->convertToDispString($fetchedRow['pc_name']);		// 名前
-		$linkUrl = $this->currentPageUrl . '&category=' . $fetchedRow['pc_id'];
-		$link = '<a href="' . $this->getUrl($linkUrl, true) . '" >' . $name . '</a>';
-		
-		$row = array(
-			'category_link' => $link
-		);
-		$this->tmpl->addVars('subcategory', $row);
-		$this->tmpl->parseTemplate('subcategory', 'a');
-		
-		// 表示中のコンテンツIDを保存
-		//$this->dispContIdArray[] = $fetchedRow['pc_id'];
-		
-		$this->subcategoryExists = true;				// サブカテゴリーが存在するかどうか
-		return true;
-	}
 	/**
 	 * 取得したデータをテンプレートに設定する
 	 *
@@ -530,28 +517,15 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 		
 		// 商品の詳細情報を取得
 		$ret = $this->db->getProductBySerial($fetchedRow['pt_serial'], $row, $row2, $row3, $row4);
-		if ($ret){
-		/*
-			// 取得値を設定
-			$this->productId = $row['pt_id'];	// 商品ID
-			$this->langId = $row['pt_language_id'];
-			$name = $row['pt_name'];		// 名前
-			$code = $row['pt_code'];		// 商品コード
-			$index = $row['pt_sort_order'];	// 表示順
-			$visible = $row['pt_visible'];	// 表示状態
-			$this->unitTypeId = $row['pt_unit_type_id'];	// 単位
-			$unitQuantity = $row['pt_unit_quantity'];		// 数量
-			$description = $row['pt_description'];			// 説明
-			$description_short = $row['pt_description_short'];		// 簡易説明
-			$keyword = $row['pt_search_keyword'];					// 検索キーワード
-			$url = $row['pt_site_url'];							// 詳細情報URL
-*/			
+		if ($ret){	
 			// 価格を取得
 			$priceArray = $this->getPrice($row2, self::STANDARD_PRICE);
 			$price = $priceArray['pp_price'];	// 価格
 			$currency = $priceArray['pp_currency_id'];	// 通貨
 			$taxType = $row['pt_tax_type_id'];					// 税種別
 			$lang = $row['pt_language_id'];					// 言語
+			$prePrice = $this->convertToDispString($priceArray['cu_symbol']);
+			$postPrice = $this->convertToDispString($priceArray['cu_post_symbol']);
 
 			// 表示額作成
 			$this->ecObj->setCurrencyType($currency, $lang);		// 通貨設定
@@ -655,7 +629,7 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 			'image_l_url' => $this->getUrl($imageUrl_l),		// ツールチップ用画像URL
 			'name' => $this->convertToDispString($row['pt_name']),		// 名前
 			'code' => $this->convertToDispString($row['pt_code']),		// 商品コード
-			'disp_total_price' => $dispPrice,				// 税込み価格
+			'disp_total_price' => $prePrice . $dispPrice . $postPrice,				// 税込み価格
 			'description_short' => $row['pt_description_short'],				// 簡易説明
 			'product_link' => $link												// 商品詳細リンク
 		);
@@ -746,5 +720,54 @@ class ec_dispProductWidgetContainer extends BaseWidgetContainer
 	{
 		return $this->gEnv->getResourceUrl() . self::PRODUCT_IMAGE_DIR . $filename;
 	}
+	/**
+	 * サブカテゴリーを取得
+	 *
+	 * @param array $category		カテゴリー
+	 * @return array				すべてのカテゴリーID
+	 */
+	function getSubCategory($category, $level = 0)
+	{
+		if (empty($category)) return array();
+		
+		$destCategory = $category;
+		
+		for ($i = 0; $i < count($category); $i++){
+			$addCategory = $this->_getChildCategory($category[$i]);
+			$destCategory = array_merge($destCategory, $addCategory);
+		}
+		return $destCategory;
+	}
+	/**
+	 * サブカテゴリーを取得
+	 *
+	 * @param int $categoryId		カテゴリーId
+	 * @return array				すべてのカテゴリーID
+	 */
+	function _getChildCategory($categoryId, $level = 0)
+	{
+		$destCategory = array();
+		
+		// メニューの階層を制限
+		if ($level >= self::MAX_CATEGORY_LEVEL) return $destCategory;
+		$level++;
+		
+		// 子カテゴリーを取得
+		$ret = $this->db->getChildCategory($categoryId, $this->langId, $rows);
+		if ($ret){
+			for ($i = 0; $i < count($rows); $i++){
+				$childCategory = $rows[$i]['pc_id'];
+				if (!in_array($childCategory, $destCategory)){
+					$addCategoryArray = $this->_getChildCategory($childCategory, $level);
+					for ($j = 0; $j < count($addCategoryArray); $j++){
+						$addCategory = $addCategoryArray[$j];
+						if (!in_array($addCategory, $destCategory)) $destCategory[] = $addCategory;
+					}
+					$destCategory[] = $childCategory;
+				}
+			}
+		}
+		return $destCategory;
+	}
 }
 ?>
