@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_ec_mainProductlistWidgetContainer.php 3183 2010-06-04 04:19:43Z fishbone $
+ * @version    SVN: $Id: admin_ec_mainProductlistWidgetContainer.php 4485 2011-12-02 03:58:15Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_ec_mainBaseWidgetContainer.php');
@@ -39,7 +39,7 @@ class admin_ec_mainProductlistWidgetContainer extends admin_ec_mainBaseWidgetCon
 		
 		// EC用共通オブジェクト取得
 		$this->ecObj = $this->gInstance->getObject(self::PRICE_OBJ_ID);
-		$this->ecObj->initByDefault();		// デフォルト値で初期化
+		//$this->ecObj->initByDefault();		// デフォルト値で初期化
 	}
 	/**
 	 * テンプレートファイルを設定
