@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_ec_menuMenudefWidgetContainer.php 5337 2012-10-27 10:05:03Z fishbone $
+ * @version    SVN: $Id: admin_ec_menuMenudefWidgetContainer.php 5388 2012-11-18 12:23:43Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_ec_menuBaseWidgetContainer.php');
@@ -33,6 +33,7 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 	private $availableLangArray;	// 利用可能な言語
 	private $categoryListData;		// 商品カテゴリー
 	private $categoryArray;			// カテゴリー設定値
+	private $catagorySelectCount;	// カテゴリー選択可能数
 	const SEARCH_WIDGET = 'ec_disp';			// 商品表示用ウィジェット
 	const DEFAULT_MENU_ID = 'ec_menu';			// デフォルトメニューID
 	const MAX_MENU_TREE_LEVEL = 5;			// メニュー階層最大数
@@ -46,9 +47,9 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 //	const CONTENT_TYPE_SMARTPHONE = 'smartphone';			// 汎用コンテンツのコンテンツタイプ(スマートフォン用)
 	const LANG_ICON_PATH = '/images/system/flag/';		// 言語アイコンパス
 	const ITEM_NAME_HEAD = 'item_name_';				// 多言語対応名前ヘッダ
-	const CATEGORY_COUNT = 2;				// 商品カテゴリーの選択可能数
 	const PARAM_CONTENT_ID = 'pcontent';	// コンテンツIDキー
 	const PARAM_CATEGORY_ID = 'category';	// カテゴリーIDキー
+	const DEFAULT_CATEGORY_COUNT = 2;	// デフォルトの商品カテゴリー選択可能数
 	
 	/**
 	 * コンストラクタ
@@ -72,6 +73,13 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 		$this->userId	= $this->gEnv->getCurrentUserId();
 		$this->langId	= $this->gEnv->getCurrentLanguage();		// 表示言語を取得
 		
+		// ウィジェットパラメータ取得
+		$paramObj = $this->getWidgetParamObj();
+		if (!empty($paramObj)){
+			$this->catagorySelectCount		= $paramObj->categoryCount;		// 商品カテゴリー選択可能数
+		}
+		if ($this->catagorySelectCount <= 0) $this->catagorySelectCount = self::DEFAULT_CATEGORY_COUNT;
+		
 		// ##### 多言語対応用データ作成 #####
 		$this->isMultiLang = $this->gEnv->isMultiLanguageSite();			// 多言語対応画面かどうか
 		$this->availableLangRows = array();
@@ -294,6 +302,7 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 		if ($parentId == '') $parentId = '0';
 		
 		$name = $request->trimValueOf('item_name');
+		$title = $request->valueOf('item_title');		// タイトル(HTML可)
 		$this->menuItemType = $request->trimValueOf('item_type');
 		if ($this->menuItemType == '') $this->menuItemType = '0';		// デフォルトの項目タイプは通常リンク
 		$linkType = $request->trimValueOf('item_link_type');
@@ -304,7 +313,7 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 		
 		// カテゴリーを取得
 		$this->categoryArray = array();
-		for ($i = 0; $i < self::CATEGORY_COUNT; $i++){
+		for ($i = 0; $i < $this->catagorySelectCount; $i++){
 			$itemName = 'item_category' . $i;
 			$itemValue = $request->trimValueOf($itemName);
 			if (!empty($itemValue)){		// 0以外の値を取得
@@ -353,7 +362,7 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 					// パラメータ作成
 					$param = self::PARAM_CATEGORY_ID . '=' . implode(',', $this->categoryArray) . '&' . self::PARAM_CONTENT_ID . '=' . $newContentId;
 			
-					$ret = $this->db->addMenuItem($this->menuId, $parentId, $nameLangStr, ''/*説明*/, 0/*項目順は自動設定*/, $this->menuItemType, $linkType, $param, $visible, $newId);
+					$ret = $this->db->addMenuItem($this->menuId, $parentId, $nameLangStr, $title, ''/*説明*/, 0/*項目順は自動設定*/, $this->menuItemType, $linkType, $param, $visible, $newId);
 				}
 				
 				// トランザクション終了
@@ -401,7 +410,7 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 					$param = self::PARAM_CATEGORY_ID . '=' . implode(',', $this->categoryArray) . '&' . self::PARAM_CONTENT_ID . '=' . $newContentId;
 					
 					// メニューを更新
-					$ret = $this->db->updateMenuItem($this->serialNo, $nameLangStr, ''/*説明*/, $this->menuItemType, $linkType, $param, $visible);
+					$ret = $this->db->updateMenuItem($this->serialNo, $nameLangStr, $title, ''/*説明*/, $this->menuItemType, $linkType, $param, $visible);
 				}
 				
 				// トランザクション終了
@@ -442,6 +451,7 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 					// 取得値を設定
 					$this->serialNo = $row['md_id'];			// ID
 					$name = $this->getDefaultLangString($row['md_name']);		// 名前
+					$title = $row['md_title'];		// タイトル(HTML可)
 					$this->menuItemType = $row['md_type'];		// 項目タイプ
 					$linkType = $row['md_link_type'];	// リンクタイプ
 					$visible = $row['md_visible'];
@@ -497,7 +507,8 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 		}
 		
 		// ### 入力値を再設定 ###
-		$this->tmpl->addVar("_widget", "name", $name);		// 名前
+		$this->tmpl->addVar("_widget", "name", $this->convertToDispString($name));		// 名前
+		$this->tmpl->addVar("_widget", "title", $this->convertToDispString($title));		// タイトル(HTML可)
 		$this->tmpl->addVar("_widget", "url", $url);		// リンク先URL
 		$this->tmpl->addVar("_widget", "disp_url", $this->convertToDispString($url));		// リンク先URL
 		$this->tmpl->addVar("_widget", "html", $html);		// ヘッダコンテンツ
@@ -776,7 +787,7 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 	 */
 	function createCategoryMenu()
 	{
-		for ($j = 0; $j < self::CATEGORY_COUNT; $j++){
+		for ($j = 0; $j < $this->catagorySelectCount; $j++){
 			// selectメニューの作成
 			$this->tmpl->clearTemplate('category_list');
 			for ($i = 0; $i < count($this->categoryListData); $i++){
