@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_menuDb.php 5333 2012-10-26 13:04:48Z fishbone $
+ * @version    SVN: $Id: ec_menuDb.php 5388 2012-11-18 12:23:43Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -97,6 +97,7 @@ class ec_menuDb extends BaseDb
 	 * @param string  $menuId		メニューID
 	 * @param string  $parentId		親メニュー項目ID
 	 * @param string  $name			メニュー名
+	 * @param string  $title		タイトル(HTML可)
 	 * @param string  $desc			説明
 	 * @param int     $index		インデックス番号(0のときは最大値を設定)
 	 * @param int     $type			項目タイプ
@@ -108,7 +109,7 @@ class ec_menuDb extends BaseDb
 	 * @param string  $contentId	リンク先コンテンツID
 	 * @return bool					true = 成功、false = 失敗
 	 */
-	function addMenuItem($menuId, $parentId, $name, $desc, $index, $type, $linkType, $param, $visible, &$newId, $contentType = '', $contentId = '')
+	function addMenuItem($menuId, $parentId, $name, $title, $desc, $index, $type, $linkType, $param, $visible, &$newId, $contentType = '', $contentId = '')
 	{
 		$now = date("Y/m/d H:i:s");	// 現在日時
 		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
@@ -135,10 +136,10 @@ class ec_menuDb extends BaseDb
 			if ($ret) $index = $maxRow['ms'] + 1;
 		}
 		$queryStr = 'INSERT INTO _menu_def ';
-		$queryStr .=  '(md_id, md_parent_id, md_index, md_menu_id, md_name, md_description, md_type, md_link_type, md_param, md_visible, md_content_type, md_content_id, md_update_user_id, md_update_dt) ';
+		$queryStr .=  '(md_id, md_parent_id, md_index, md_menu_id, md_name, md_title, md_description, md_type, md_link_type, md_param, md_visible, md_content_type, md_content_id, md_update_user_id, md_update_dt) ';
 		$queryStr .=  'VALUES ';
-		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
-		$this->execStatement($queryStr, array($id, $parentId, $index, $menuId, $name, $desc, $type, $linkType, $param, intval($visible), $contentType, $contentId, $userId, $now));
+		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
+		$this->execStatement($queryStr, array($id, $parentId, $index, $menuId, $name, $title, $desc, $type, $linkType, $param, intval($visible), $contentType, $contentId, $userId, $now));
 		
 		// 新規のシリアル番号取得
 		$queryStr = 'select max(md_id) as ns from _menu_def ';
@@ -154,6 +155,7 @@ class ec_menuDb extends BaseDb
 	 *
 	 * @param int     $id			メニュー項目ID
 	 * @param string  $name			メニュー名
+	 * @param string  $title		タイトル(HTML可)
 	 * @param string  $desc			説明
 	 * @param int     $type			項目タイプ
 	 * @param int     $linkType		リンクタイプ
@@ -163,7 +165,7 @@ class ec_menuDb extends BaseDb
 	 * @param string  $contentId	リンク先コンテンツID
 	 * @return bool					true = 成功、false = 失敗
 	 */
-	function updateMenuItem($id, $name, $desc, $type, $linkType, $param, $visible, $contentType = '', $contentId = '')
+	function updateMenuItem($id, $name, $title, $desc, $type, $linkType, $param, $visible, $contentType = '', $contentId = '')
 	{
 		$now = date("Y/m/d H:i:s");	// 現在日時
 		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
@@ -178,6 +180,7 @@ class ec_menuDb extends BaseDb
 		$params = array();
 		$queryStr = 'UPDATE _menu_def ';
 		$queryStr .=  'SET md_name = ?, ';			$params[] = $name;
+		$queryStr .=    'md_title = ?, ';			$params[] = $title;
 		$queryStr .=    'md_description = ?, ';		$params[] = $desc;
 		$queryStr .=    'md_type = ?, ';			$params[] = $type;
 		$queryStr .=    'md_link_type = ?, ';		$params[] = $linkType;
