@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_product_displayWidgetContainer.php 4182 2011-06-11 12:49:18Z fishbone $
+ * @version    SVN: $Id: ec_product_displayWidgetContainer.php 4484 2011-11-29 22:30:18Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
@@ -84,7 +84,7 @@ class ec_product_displayWidgetContainer extends BaseWidgetContainer
 		if (empty($categoryId) && empty($productId) && empty($task)){
 			return 'main.tmpl.html';
 		} else {
-			return 'main_none.tmpl.html';
+			return '';
 		}
 	}
 	/**
@@ -101,7 +101,8 @@ class ec_product_displayWidgetContainer extends BaseWidgetContainer
 		// 商品や商品カテゴリーが表示されているときは表示しない
 		$categoryId = $request->trimValueOf('category');	// カテゴリーID
 		$productId = $request->trimValueOf('product');			// 製品ID
-		if (!empty($categoryId) || !empty($productId)) return;
+		$task = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TASK);
+		if (!empty($categoryId) || !empty($productId) || !empty($task)) return;
 		
 		// 環境取得
 		$this->langId	= $this->gEnv->getCurrentLanguage();		// 表示言語を取得
