@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_product_slideWidgetContainer.php 5379 2012-11-13 08:49:20Z fishbone $
+ * @version    SVN: $Id: ec_product_slideWidgetContainer.php 5387 2012-11-16 14:49:51Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -41,6 +41,9 @@ class ec_product_slideWidgetContainer extends BaseWidgetContainer
 	const DEFAULT_CSS_FILE = '/default.css';	// CSSファイル
 	const DEFAULT_PRODUCT_IMAGE_TYPE = 'c.jpg';			// 商品画像ファイルのタイプ
 	const PRODUCT_IMAGE_DIR = '/widgets/product/image/';				// 商品画像格納ディレクトリ
+	const MAX_CATEGORY_LEVEL = 5;			// カテゴリー階層最大数
+	// Eコマース設定DB値
+	const CF_E_HIERARCHICAL_CATEGORY	= 'hierarchical_category';	// 階層化商品カテゴリー
 	
 	/**
 	 * コンストラクタ
@@ -112,6 +115,10 @@ class ec_product_slideWidgetContainer extends BaseWidgetContainer
 			$categoryId = '';		// すべて数値であるかチェック
 			$categoryArray = array();
 		}
+		if (!empty($categoryArray) && $this->ecObj->getConfig(self::CF_E_HIERARCHICAL_CATEGORY)){			// サブカテゴリーを取得する場合
+			$categoryArray = array_unique($this->getSubCategory($categoryArray));
+			$categoryId = implode(',', $categoryArray);
+		}
 		
 		// 商品リストを取得
 		$this->db->getProductSerial($this->langId, $viewCount, 0, $categoryArray, $rows);
@@ -295,5 +302,54 @@ class ec_product_slideWidgetContainer extends BaseWidgetContainer
 	{
 		return $this->gEnv->getResourceUrl() . self::PRODUCT_IMAGE_DIR . $filename;
 	}
+	/**
+	 * サブカテゴリーを取得
+	 *
+	 * @param array $category		カテゴリー
+	 * @return array				すべてのカテゴリーID
+	 */
+	function getSubCategory($category, $level = 0)
+	{
+		if (empty($category)) return array();
+		
+		$destCategory = $category;
+		
+		for ($i = 0; $i < count($category); $i++){
+			$addCategory = $this->_getChildCategory($category[$i]);
+			$destCategory = array_merge($destCategory, $addCategory);
+		}
+		return $destCategory;
+	}
+	/**
+	 * サブカテゴリーを取得
+	 *
+	 * @param int $categoryId		カテゴリーId
+	 * @return array				すべてのカテゴリーID
+	 */
+	function _getChildCategory($categoryId, $level = 0)
+	{
+		$destCategory = array();
+		
+		// メニューの階層を制限
+		if ($level >= self::MAX_CATEGORY_LEVEL) return $destCategory;
+		$level++;
+		
+		// 子カテゴリーを取得
+		$ret = $this->db->getChildCategory($categoryId, $this->langId, $rows);
+		if ($ret){
+			for ($i = 0; $i < count($rows); $i++){
+				$childCategory = $rows[$i]['pc_id'];
+				if (!in_array($childCategory, $destCategory)){
+					$addCategoryArray = $this->_getChildCategory($childCategory, $level);
+					for ($j = 0; $j < count($addCategoryArray); $j++){
+						$addCategory = $addCategoryArray[$j];
+						if (!in_array($addCategory, $destCategory)) $destCategory[] = $addCategory;
+					}
+					$destCategory[] = $childCategory;
+				}
+			}
+		}
+		return $destCategory;
+	}
 }
 ?>
