@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_product_slideDb.php 5372 2012-11-11 11:07:46Z fishbone $
+ * @version    SVN: $Id: ec_product_slideDb.php 5387 2012-11-16 14:49:51Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -195,5 +195,23 @@ class ec_product_slideDb extends BaseDb
 		$ret = $this->selectRecord($queryStr, array($type), $row);
 		return $ret;
 	}
+	/**
+	 * サブ商品カテゴリーを取得
+	 *
+	 * @param int		$id			カテゴリーID
+	 * @param string	$langId		言語ID
+	 * @param array  $rows			取得レコード
+	 * @return bool					true=取得、false=取得せず
+	 */
+	function getChildCategory($id, $langId, &$rows)
+	{
+		$queryStr  = 'SELECT * FROM product_category ';
+		$queryStr .=   'WHERE pc_deleted = false ';	// 削除されていない
+		$queryStr .=     'AND pc_parent_id = ? ';
+		$queryStr .=     'AND pc_language_id = ? ';
+		$queryStr .=   'ORDER BY pc_sort_order';
+		$retValue = $this->selectRecords($queryStr, array($id, $langId), $rows);
+		return $retValue;
+	}
 }
 ?>
