@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: diff.inc.php 1095 2008-10-21 08:51:41Z fishbone $
+ * @version    SVN: $Id: diff.inc.php 1601 2009-03-21 05:51:06Z fishbone $
  * @link       http://www.magic3.org
  */
 // Copyright (C)
@@ -135,29 +135,17 @@ function plugin_diff_delete($page)
 
 	$s_page = htmlspecialchars($page);
 	// modified for Magic3 by naoki on 2008/10/6
-	/*$body .= <<<EOD
-<p>$_msg_diff_adminpass</p>
-<form action="$script" method="post">
- <div>
-  <input type="hidden"   name="cmd"    value="diff" />
-  <input type="hidden"   name="page"   value="$s_page" />
-  <input type="hidden"   name="action" value="delete" />
-  <input type="password" name="pass"   size="12" />
-  <input type="submit"   name="ok"     value="$_btn_delete" />
- </div>
-</form>
-EOD;*/
 	$postScript = $script . WikiParam::convQuery("?");
 	$body .= <<<EOD
 <p>$_msg_diff_adminpass</p>
-<form action="$postScript" method="post">
+<form action="$postScript" method="post" class="form">
  <div>
   <input type="hidden"   name="wcmd"    value="diff" />
   <input type="hidden"   name="page"   value="$s_page" />
   <input type="hidden"   name="action" value="delete" />
   <input type="hidden"   name="pass" />
   <input type="password" name="password" size="12" />
-  <input type="submit"   name="ok"     value="$_btn_delete" onclick="this.form.pass.value = hex_md5(this.form.password.value);" />
+  <input type="submit"   name="ok"     class="button" value="$_btn_delete" onclick="this.form.pass.value = hex_md5(this.form.password.value);" />
  </div>
 </form>
 EOD;
